@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Base role for JSON Schema vocabulary classes
 
-our $VERSION = '0.513';
+our $VERSION = '0.514';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -80,7 +80,7 @@ JSON::Schema::Modern::Vocabulary - Base role for JSON Schema vocabulary classes
 
 =head1 VERSION
 
-version 0.513
+version 0.514
 
 =head1 SYNOPSIS
 
@@ -115,7 +115,7 @@ The list of keywords defined by the vocabulary. Must be implemented by the compo
 
 =head2 traverse
 
-Traverses a subschema.
+Traverses a subschema. Callers are expected to establish a new C<$state> scope.
 
 =head2 traverse_subschema
 
@@ -135,7 +135,7 @@ Recursively traverses the subschema under one property of the object at the curr
 
 =head2 eval
 
-Evaluates a subschema.
+Evaluates a subschema. Callers are expected to establish a new C<$state> scope.
 
 =head1 SUPPORT
 
